How does it looks like?
=======================

The following screenshots are just for demonstration purposes only:

Index page
----------

.. image:: _static/screenshots/latest-posts.png

Post view
---------

.. image:: _static/screenshots/post-view.png

Tag view
--------

.. image:: _static/screenshots/tag-view.png
